<?php

// =============================== Flickr widget ======================================
class Woo_FlickrWidget extends WP_Widget {

	private $defaults = array( 'id' => '', 'number' => '' );

	function __construct() {
		$widget_ops = array( 'description' => 'This Flickr widget populates photos from a Flickr ID.' );
		parent::__construct( false, __( 'Woo - Flickr', 'woothemes' ), $widget_ops );
	}

	function widget( $args, $instance ) {
		extract( $args );

		// Note:  Normally a widget fetches its settings from $instance, but for the sake of backwards
		// compatibility for this older theme, we will continue to use options here
		$settings = get_option( "widget_flickrwidget" );
		$settings = wp_parse_args( (array) $settings, $this->defaults );

		$id = $settings['id'];
		$number = $settings['number'];

		echo $before_widget;
		echo $before_title; ?>
		<?php _e( 'Photos on <span>flick<span>r</span></span>', 'woothemes' ); ?>
		<?php echo $after_title; ?>

		<div class="wrap">
			<div class="fix"></div>
			<script type="text/javascript" src="http://www.flickr.com/badge_code_v2.gne?count=<?php echo $number; ?>&amp;display=latest&amp;size=s&amp;layout=x&amp;source=user&amp;user=<?php echo $id; ?>"></script>
			<div class="fix"></div>
		</div>

		<?php
		echo $after_widget;
	}

	function form( $instance ) {

		$settings = get_option( "widget_flickrwidget" );
		$settings = wp_parse_args( (array) $settings, $this->defaults );

		// check if anything's been sent
		if ( isset( $_POST['update_flickr'] ) ) {
			$settings['id'] = sanitize_text_field( $_POST['flickr_id'] );
			$settings['number'] = sanitize_text_field( $_POST['flickr_number'] );
			update_option( "widget_flickrwidget", $settings );
		}

		echo '<p>
				<label for="flickr_id">Flickr ID (<a href="http://www.idgettr.com">idGettr</a>):
				<input id="flickr_id" name="flickr_id" type="text" class="widefat" value="' . esc_attr( $settings['id'] ) . '" /></label></p>';
		echo '<p>
				<label for="flickr_number">Number of photos:
				<input id="flickr_number" name="flickr_number" type="text" class="widefat" value="' . esc_attr( $settings['number'] ) . '" /></label></p>';
		echo '<input type="hidden" id="update_flickr" name="update_flickr" value="1" />';
	}
}

// =============================== Twitter widget ======================================
class Woo_TwitterWidget extends WP_Widget {

	private $defaults = array( 'username' => '', 'number' => 5, 'title' => 'Twitter' );

	function __construct() {
		$widget_ops = array( 'description' => 'Add your Twitter feed to your sidebar with this widget.' );
		parent::__construct( false, __( 'Woo - Twitter Stream', 'woothemes' ), $widget_ops );
	}

	function widget( $args, $instance ) {
		extract( $args );

		// Note:  Normally a widget fetches its settings from $instance, but for the sake of backwards
		// compatibility for this older theme, we will continue to use options here
		$settings = get_option( "widget_twitterwidget" );
		$settings = wp_parse_args( (array) $settings, $this->defaults );

		echo $before_widget;
		echo $before_title . esc_html( $settings['title'] ) . $after_title;
		?>
			<ul id="twitter_update_list"><li></li></ul>
		<?php
		echo $after_widget;
	}

	function form( $instance ) {

		$settings = get_option( "widget_twitterwidget" );
		$settings = wp_parse_args( (array) $settings, $this->defaults );

		// check if anything's been sent
		if ( isset( $_POST['update_twitter'] ) ) {
			$settings['username'] = sanitize_text_field( $_POST['twitter_username'] );
			$settings['number'] = sanitize_text_field( $_POST['twitter_number'] );
			$settings['title'] = sanitize_text_field( $_POST['twitter_title'] );
			update_option( "widget_twitterwidget", $settings );
		}

		echo '<p>
			<label for="twitter_username">Twitter username:
			<input id="twitter_username" name="twitter_username" type="text" class="widefat" value="'. esc_attr( $settings['username'] ) . '" /></label></p>';

		echo '<p>
			<label for="twitter_number">Number of tweets (default = 5):
			<input id="twitter_number" name="twitter_number" type="text" class="widefat" value="'. esc_attr( $settings['number'] ) . '" /></label></p>';
		echo '<p>
			<label for="twitter_title">Title
			<input id="twitter_title" name="twitter_title" type="text" class="widefat" value="' . esc_attr( $settings['title'] ) . '" /></label></p>';
		echo '<input type="hidden" id="update_twitter" name="update_twitter" value="1" /></label>';
	}
}

// =============================== Tabs widget ======================================

class Woo_Tabs extends WP_Widget {

	private $defaults = array( 'number' => 5, 'thumb_size' => 35 );

	function __construct() {
		$widget_ops = array( 'description' => 'This widget is the Tabs that classicaly goes into the sidebar. It contains the Popular posts, Latest Posts, Recent comments and a Tag cloud.' );
		parent::__construct( false, $name = __( 'Woo - Tabs', 'woothemes' ), $widget_ops );
	}

	function widget( $args, $instance ) {
		extract( $args );

		$instance = wp_parse_args( (array) $instance, $this->defaults );
		$number = $instance['number'];
		$thumb_size = $instance['thumb_size'];
		?>

		<div id="tabs">

			<ul class="wooTabs">
				<li class="popular"><a href="#tab-pop"><?php _e('Popular', 'woothemes'); ?></a></li>
				<li class="latest"><a href="#tab-latest"><?php _e('Latest', 'woothemes'); ?></a></li>
				<li class="comments"><a href="#tab-comm"><?php _e('Comments', 'woothemes'); ?></a></li>
				<li class="tags"><a href="#tab-tags"><?php _e('Tags', 'woothemes'); ?></a></li>
			</ul>

			<div class="clear"></div>

			<div class="boxes box inside">

				<ul id="tab-pop" class="list">
					<?php if ( function_exists('woo_tabs_popular') ) woo_tabs_popular($number, $thumb_size); ?>
				</ul>

				<ul id="tab-latest" class="list">
					<?php if ( function_exists('woo_tabs_latest') ) woo_tabs_latest($number, $thumb_size); ?>
				</ul>

				<ul id="tab-comm" class="list">
					<?php if ( function_exists('woo_tabs_comments') ) woo_tabs_comments($number, $thumb_size); ?>
				</ul>

				<div id="tab-tags" class="list">
					<?php wp_tag_cloud('smallest=12&largest=20'); ?>
				</div>

			</div><!-- /.boxes -->

		</div><!-- /wooTabs -->

		<div style="height: 25px ! important;" class="fix"></div>

		<?php
	}

	function update($new_instance, $old_instance) {
		$settings = array( 'number' => 5, 'thumb_size' => 35 );
		if ( isset( $new_instance['number'] ) ) {
			$settings['number'] = intval( $new_instance['number'] );
		}
		if ( isset( $new_instance['thumb_size'] ) ) {
			$settings['thumb_size'] = intval( $new_instance['thumb_size'] );
		}
		return $settings;
	}

	function form($instance) {

		$instance = wp_parse_args( (array) $instance, $this->defaults );
		$number = $instance['number'];
		$thumb_size = $instance['thumb_size'];

		?>
		<p>
			<label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Number of posts:','woothemes'); ?>
			<input class="widefat" id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo esc_attr( $number ); ?>" />
			</label>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id('thumb_size') ); ?>"><?php _e( 'Thumbnail Size (0=disable):', 'woothemes' ); ?>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('thumb_size') ); ?>" name="<?php echo esc_attr( $this->get_field_name('thumb_size') ); ?>" type="text" value="<?php echo esc_attr( $thumb_size ); ?>" />
			</label>
		</p>
		<?php
	}

}

/*---------------------------------------------------------------------------------*/
/* Adspace 125x125 Widget */
/*---------------------------------------------------------------------------------*/

class Woo_Ad125Widget extends WP_Widget {

	private $defaults = array( 'number' => 4 );

	function __construct() {
		$widget_ops = array('description' => 'Use this widget to add 125x125 Ads as a widget.' );
		parent::__construct( false, __( 'Woo - Ads 125x125', 'woothemes' ), $widget_ops );
	}

	function widget($args, $instance) {
		extract( $args );
		$instance = wp_parse_args( (array) $instance, $this->defaults );

		$number = $instance['number'];
		if ($number == 0) $number = 1;
		if ($number > 4) $number =4;
		$img_url = array();
		$dest_url = array();

		$numbers = range(1,$number);
		$counter = 0;

		if (get_option('woo_ads_rotate') == "true") {
			shuffle($numbers);
		}
		?>
		<div class="ads-125 widget">
		<?php
			foreach ($numbers as $number) {
				$counter++;
				$img_url[$counter] = get_option('woo_ad_image_'.$number);
				$dest_url[$counter] = get_option('woo_ad_url_'.$number);

		?>
		        <a href="<?php echo esc_url( $dest_url[$counter] ); ?>"><img src="<?php echo esc_url( $img_url[$counter] ); ?>" alt="Ad" /></a>
		<?php } ?>
		</div>
		<!--/ads -->
		<?php
	}

	function update($new_instance, $old_instance) {
		$settings['number'] = 4;
		if ( isset( $new_instance['number'] ) && 4 > intval( $new_instance['number'] ) ) {
			$settings['number'] = intval( $new_instance['number'] );
		}
		return $settings;
	}

	function form($instance) {

		$instance = wp_parse_args( (array) $instance, $this->defaults );
		$number = $instance['number'];
		?>
        <p>
            <label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Number of ads (1-4):','woothemes'); ?></label>
            <input type="text" name="<?php echo $this->get_field_name('number'); ?>" value="<?php echo esc_attr( $number ); ?>" class="widefat" id="<?php echo $this->get_field_id('number'); ?>" />
        </p>
        <?php
	}
}

// =============================== Author widget ======================================

class Woo_AuthorWidget extends WP_Widget {

	private $defaults = array( 'title' => '' );

	function __construct() {
		$widget_ops = array('description' => 'This is a WooThemes Blog Author Info widget.' );
		parent::__construct( false, __( 'Woo - Blog Author Info', 'woothemes' ), $widget_ops );
	}

	function widget( $args, $instance ) {
		if ( ! is_single() ) {
			return;
		}

		extract( $args );
		$settings = get_option( "widget_authorwidget" );
		$settings = wp_parse_args( (array) $settings, $this->defaults );

		$title = $settings['title'];
		if ( $title == "" ) {
			$title = __( 'Author Info', 'woothemes' );
		}

		echo $before_widget;
		if ( $title ) {
			echo $before_title . $title . $after_title;
		}

		$author_id = get_the_author_meta( 'ID' );

		?>
		<div class="wrap">
			<div class="fl"><?php echo get_avatar( $author_id, '48' ); ?></div>
				<span class="author-info"><?php _e('This post was written by', 'woothemes'); ?> <?php the_author_posts_link(); ?> <?php _e('who has written', 'woothemes'); ?> <?php the_author_posts(); ?> <?php _e('posts on', 'woothemes'); ?> <a href="<?php echo get_option('home'); ?>/"><?php bloginfo('name'); ?></a>.</span>
			<br class="fix"></br>
			<p class="author-desc"><?php the_author_meta( 'description' ); ?></p>
		</div>
		<?php

		echo $after_widget;
	}

	function form( $instance ) {
		$settings = get_option( "widget_authorwidget" );
		$settings = wp_parse_args( (array) $settings, $this->defaults );

		// check if anything's been sent
		if ( isset( $_POST['update_author'] ) ) {
			$settings['title'] = sanitize_text_field( $_POST['author_title'] );

			update_option("widget_authorwidget",$settings);
		}

		echo '<p>
				<label for="author_title">Title:
				<input id="author_title" name="author_title" type="text" class="widefat" value="' . esc_attr( $settings['title'] ) . '" /></label></p>';
		echo '<p>
				 <small>NOTE: This widget will only show on single post page.</small>
			  </p>';
		echo '<input type="hidden" id="update_author" name="update_author" value="1" />';
	}
}

// ====================================================================================

function dailyedition_register_widgets() {
	register_widget( 'Woo_FlickrWidget' );
	register_widget( 'Woo_TwitterWidget' );
	register_widget( 'Woo_Tabs' );
	register_widget( 'Woo_Ad125Widget' );
	register_widget( 'Woo_AuthorWidget' );
}

add_action( 'widgets_init', 'dailyedition_register_widgets' );

/* Deregister Default Widgets */
function woo_deregister_widgets(){
	unregister_widget('WP_Widget_Search');
}
add_action('widgets_init', 'woo_deregister_widgets');
